abacusai.playground_text — AbacusAI documentation

# abacusai.playground_text

## Classes

`PlaygroundText` | The text content inside of a playground segment.

## Module Contents

class abacusai.playground_text.PlaygroundText(client, playgroundText=None, renderingCode=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The text content inside of a playground segment.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - playgroundText (str) – The text of the playground segment.

    - renderingCode (str) – The rendering code of the playground segment.

  playground_text
  rendering_code
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict